// mozileUtilities.js

/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/*******

Mozile Utilities Javascript
Mozile version 0.6.18

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2005-02-04

HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.
	onbeforeunload moved to mozileConfiguration.js

DESCRIPTION:
	General functions which belong nowhere else.

*********/


var mozileDebugArray = new Array();

/**
Mozile Debug Levels.
0 = Really important, alert the user right away, add to debug array
1 = Important, always show this in the status, add to debug array
2 = Not important, add to debug array
3 = Unimportant, add to debug array
*/
function mozileDebug(f,level,msg,minimise) {
	var mozileDebugLevel = mozilePrefs.getIntPref("mozile.debugLevelInt");
	
	// act only if the level of the message is higher than the mozileDebugLevel
	
	if( (level > 1 && mozileDebugLevel < 1) || (level > 2 && mozileDebugLevel < 2) ) {
		// Ignore these debug events
	}
	else {
		// Log to the debugging array	
		var datestamp = 
		mozileDD('FullYear')	+"-"+
		mozileDD('Month')			+"-"+
		mozileDD('Date')			+" "+
		mozileDD('Hours')			+":"+
		mozileDD('Minutes')		+":"+
		mozileDD('Seconds');

		var entry = new Array(datestamp,f,level,msg);
		mozileDebugArray.push(entry);

		// Critical behaviours
		if(level <= 1) {
  		var message = "Mozile: ["+ f +"] "+ msg; 
  		if(level == 0) {
				minimise ? alert(msg) : alert(message);
  		}
  		if(level == 1) {
  			window.status = message.substr(0,250);
  		}
		}
	}
}

	// Returns date strings as two digits (with leading "0") if they are 1 digit long
var mozileDates = new Object();

function mozileDD(command) {
		// first see if we've already recorded it...
	if(command in mozileDates) {
		return mozileDates[command];
	}
	
	var d = new Date();
	var commandString = "d.get"+command+"()";
	var str = eval(commandString)+"";
	if(str.length==1) {
		str = "0"+str;
	}
	if(command=="FullYear" || command=="Month" || command=="Date") {
		mozileDates[command]=str;
	}

	return str;
}

function mozileDebugAlert() {
	alert(mozileDebugArray);
}


function mozileGetContext(sel) {
	var f = ["mozileUtilities.js","mozileGetContext"];

	try {
		if ( sel.anchorNode != null ) {
		  var aN = sel.anchorNode;
			if( aN.nodeType == Node.ELEMENT_NODE ) {
//				mozileDebug(f,3,"Selection anchorNode: "+aN.nodeName);
				return aN;
 			}
 			if ( aN.parentNode != null ) {
				var aNpN = aN.parentNode;
   			if( aNpN.nodeType == Node.ELEMENT_NODE ) {
// 					mozileDebug(f,3,"Selection parentNode: "+aNpN.nodeName);
   				return aNpN;
   			}
			}
		}
		else {
			mozileDebug(f,0,"No Node!");
		}
	}
	catch(e) {
		mozileDebug(f,0,"Exception: "+e);
		return null;
	}
	return null;
}



function mozileRemoveChildren(node) {	
	var f = ["mozileUtilities.js","mozileRemoveChildren"];
//	mozileDebug(f,3,"Removing Children of: "+ node + node.id );
	
	if(node.hasChildNodes()!=true) {
		return node;
	}
//	mozileDebug(f,3,"Number of Children: "+node.childNodes.length);
	try {
		while(node.childNodes.length > 0) {
			node.removeChild(node.firstChild);
		}
	} catch(e) {
		mozileDebug(f,3,"Error: "+e);
	}
//	mozileDebug(f,3,"Number of Children left: "+node.childNodes.length);
	return node;
}



function mozileAlert(name) {
	alert("Mozile Alert: "+name);
}	


function printXML(XML) {
	var objXMLSerializer = new XMLSerializer;
	var output = objXMLSerializer.serializeToString(XML);
		// fix stupid uppercase tags!
	output = output.replace( /<(\/?)([A-Z]+)/g,
		function (output,p1,p2,offset,s) {
			return '<'+p1+p2.toLowerCase() ;
		} ) ;
	return output;
}

function dumpText(text) {
	var ta = document.getElementById("here");
	ta = mozileRemoveChildren(ta);
	var tn = document.createTextNode(text);
	ta.appendChild(tn);
}

function dumpXML(XML) {
	dumpText(printXML(XML));
}


/**
Insert single Unicode character.
It inserts a character, not an entity, so could do with renaming.

@param {number} charCode
*/
function mozileInsertEntity( charCode ) {
	var f = ["mozileUtilities.js","mozileInsertEntity"];
	try {
		mozileDoTyping();
		mozileSelection.insertCharacter( charCode );
		mozileMarkupInput();
	} catch (e) {
		mozileDebug(f,0,"Exception inserting special char: "+e);
	}
}

